forecastWrapper: Internal forecasting wrapper function

View source: R/Forecaster.R

forecastWrapperR Documentation

Internal forecasting wrapper function

Description

This function is for internal use only and may change in future releases without notice. Users should use nowcast() instead for a stable and supported interface. Helper function to check parameter vectors for positive signed integer values

Usage

forecastWrapper(
  target_variables,
  quarterly_predictors,
  factors,
  target_variable_delay,
  quarterly_delay,
  lag_estim_criterion,
  max_fcast_horizon,
  max_ar_lag_order,
  max_predictor_lag_order,
  jitter
)

TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.