mixed_freq_factor_model: Mixed-frequency factor model dataset

mixed_freq_factor_modelR Documentation

Mixed-frequency factor model dataset

Description

This dataset contains simulated mixed-frequency factor model data for examples in TwoStepSDFM.

Usage

mixed_freq_factor_model

Format

A SimulData containing the following elements:

data

If starting_date is provided, a zoo object, else, a (no_of_vars \times no_of_obs) numeric matrix holding the simulated data.

factors

If starting_date is provided, a zoo object, else a (no_of_factors \times no_of_obs) numeric matrix holding the simulated latent factors.

trans_var_coeff

Numeric (no_of_factors \times (no_of_factors * factor_lag_order)) factor VAR coefficient matrix.

loading_matrix

Numeric factor loading matrix.

meas_error

If starting_date is provided, a zoo object, else a (no_of_vars \times no_of_obs) numeric matrix holding the fundamental measurement errors.

meas_error_var_cov

Numeric measurement error variance-covariance matrix.

trans_error_var_cov

Numeric transition error variance-covariance matrix.

frequency

Integer vector of variable frequencies.

delay

Integer vector of variable delays, measured as the number of months since the latest available observation.

Generated via Generated via simFM(). For details see mixed_freq_factor_model$call.


TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.