plot.KFSFit: Generic plotting function for KFSFit S3 objects

View source: R/KalmanFilterSmoother.R

plot.KFSFitR Documentation

Generic plotting function for KFSFit S3 objects

Description

Create diagnostic plots for a KFSFit object.

Usage

## S3 method for class 'KFSFit'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)

Arguments

x

KFSFit object.

axis_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., text = element_text(size = axis_text_size)).

legend_title_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., legend.title = element_text(size = legend_title_text_size)).

...

Additional parameters for the plotting functions.

Value

A named list of patchwork/ggplot objects:

⁠Factor Time Series Plots⁠

patchwork/ggplot object graphing the estimated factors over time with 95% confidence bands based on the smoother uncertainty of the Kalman Filter and Smoother.

Author(s)

Domenic Franjic


TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.