plot.SDFMcrossVal: Generic plotting function for SDFMcrossVal S3 objects

View source: R/CrossVal.R

plot.SDFMcrossValR Documentation

Generic plotting function for SDFMcrossVal S3 objects

Description

Generic plotting function for SDFMcrossVal S3 objects

Usage

## S3 method for class 'SDFMcrossVal'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)

Arguments

x

SDFMcrossVal object.

axis_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., text = element_text(size = axis_text_size)).

legend_title_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., legend.title = element_text(size = legend_title_text_size)).

...

Additional parameters for the plotting functions.

Value

A named list of ggplot objects:

⁠CV Results⁠

ggplot object of the cross-validation error against the log Ridge penalty. The overall sparsity level of the loading matrix induced by the lasso penalty is indicated by point shapes and colours.

⁠BIC Results⁠

ggplot object of the BIC against the log Ridge penalty. The overall sparsity level of the loading matrix induced by the lasso penalty is indicated by point shapes and colours.

Author(s)

Domenic Franjic


TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.