plot.SDFMnowcast: Generic plotting function for SDFMnowcast S3 objects

View source: R/Nowcast.R

plot.SDFMnowcastR Documentation

Generic plotting function for SDFMnowcast S3 objects

Description

Generic plotting function for SDFMnowcast S3 objects

Usage

## S3 method for class 'SDFMnowcast'
plot(x, axis_text_size = 20, ...)

Arguments

x

SDFMnowcast object.

axis_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., text = element_text(size = axis_text_size)).

...

Additional parameters for the plotting functions.

Value

A named list storing of ggplot objects:

⁠Single Pred. Fcast Density Plots x⁠

patchwork / ggplot objects graphing the distribution of forecasts generated by the predictors for each prediction (backcasts, nowcasts, forecasts) for each target, respectively. Altogether, there will be as many such objects as there are targets, with x replaced by the column name of the target.

Author(s)

Domenic Franjic


TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.