plot.SPCAFit: Generic plotting function for SPCAFit S3 objects

plot.SPCAFitR Documentation

Generic plotting function for SPCAFit S3 objects

Description

Create diagnostic plots for an SPCAFit object.

Usage

## S3 method for class 'SPCAFit'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)

Arguments

x

SPCAFit object.

axis_text_size

Numeric size of x- and y-axis labels. Passed to ggplot2 theme(..., text = element_text(size = axis_text_size)).

legend_title_text_size

Numeric size of x- and y-axis labels. Passed to ggplot2 theme(..., legend.title = element_text(size = legend_title_text_size)).

...

Additional parameters for the plotting functions.

Value

A named list of plot objects:

⁠Factor Time Series Plots⁠

patchwork/ggplot object showing the estimated factors over time.

⁠Loading Matrix Heatmap⁠

ggplot object showing a heatmap of the estimated factor loadings. Zeros are highlighted in black.

⁠Meas. Error Var.-Cov. Matrix Heatmap⁠

ggplot object showing a heatmap of the measurement error variance–covariance matrix.

⁠Eigenvalue Plot⁠

ggplot object showing a bar plot of the eigenvalues of the measurement error variance–covariance matrix.

Author(s)

Domenic Franjic


TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.