plot.SimulData: Generic plotting function for SimulData S3 objects

View source: R/SimFM.r

plot.SimulDataR Documentation

Generic plotting function for SimulData S3 objects

Description

Create diagnostic plots for an SimulData object.

Usage

## S3 method for class 'SimulData'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)

Arguments

x

SimulData object.

axis_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., text = element_text(size = axis_text_size)).

legend_title_text_size

Numeric size of x- and y-axis labels. Prased to ggplot2 theme(..., legend.title = element_text(size = legend_title_text_size)).

...

Additional parameters for the plotting functions.

Value

A named list of plot objects:

⁠Factor Time Series Plots⁠

patchwork/ggplot object showing the simulated factors over time.

⁠Loading Matrix Heatmap⁠

ggplot object showing a heatmap of the simulated factor loadings. Zeros are highlighted in black.

⁠Meas. Error Var.-Cov. Matrix Heatmap⁠

ggplot object showing a heatmap of the measurement error variance-covariance matrix.

⁠Meas. Error Var.-Cov. Eigenvalue Plot⁠

ggplotobject showing a bar plot of the eigenvalues of the measurement error variance-covariance matrix.

⁠Data Var.-Cov. Matrix Heatmap⁠

ggplot object showing a heatmap of the data variance-covariance matrix.

⁠Data Var.-Cov. Eigenvalue Plot⁠

ggplot object showing a bar plot of the eigenvalues of the data variance-covariance matrix.


TwoStepSDFM documentation built on May 19, 2026, 9:07 a.m.