| factor_model | R Documentation |
This is a simulated factor model dataset for demonstration and testing
with TwoStepSDFM.
factor_model
A SimulData containing the following elements:
If starting_date is provided, a zoo object, else,
a (no_of_vars \times no_of_obs) numeric matrix holding the
simulated data.
If starting_date is provided, a zoo object, else a
(no_of_factors \times no_of_obs) numeric matrix holding the
simulated latent factors.
Numeric (no_of_factors \times
(no_of_factors * factor_lag_order)) factor VAR coefficient matrix.
Numeric factor loading matrix.
If starting_date is provided, a zoo object, else
a (no_of_vars \times no_of_obs) numeric matrix holding the
fundamental measurement errors.
Numeric measurement error variance-covariance matrix.
Numeric transition error variance-covariance matrix.
Integer vector of variable frequencies.
Integer vector of variable delays, measured as the number of months since the latest available observation.
Generated via simFM(). For details see factor_model$call.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.