| plot.SDFMcrossVal | R Documentation |
Generic plotting function for SDFMcrossVal S3 objects
## S3 method for class 'SDFMcrossVal'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)
x |
|
axis_text_size |
Numeric size of x- and y-axis labels. Prased to ggplot2
|
legend_title_text_size |
Numeric size of x- and y-axis labels. Prased to
ggplot2
|
... |
Additional parameters for the plotting functions. |
A named list of ggplot objects:
CV Resultsggplot object of the cross-validation error against
the log Ridge penalty. The overall sparsity level of the loading matrix
induced by the lasso penalty is indicated by point shapes and colours.
BIC Resultsggplot object of the BIC against the log Ridge
penalty. The overall sparsity level of the loading matrix induced by the
lasso penalty is indicated by point shapes and colours.
Domenic Franjic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.