| plot.SDFMnowcast | R Documentation |
Generic plotting function for SDFMnowcast S3 objects
## S3 method for class 'SDFMnowcast'
plot(x, axis_text_size = 20, ...)
x |
|
axis_text_size |
Numeric size of x- and y-axis labels. Prased to ggplot2
|
... |
Additional parameters for the plotting functions. |
A named list storing of ggplot objects:
Single Pred. Fcast Density Plots xpatchwork / ggplot objects
graphing the distribution of forecasts generated by the predictors for
each prediction (backcasts, nowcasts, forecasts) for each target,
respectively. Altogether, there will be as many such objects as there are
targets, with x replaced by the column name of the target.
Domenic Franjic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.