| plot.SPCAFit | R Documentation |
Create diagnostic plots for an SPCAFit object.
## S3 method for class 'SPCAFit'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)
x |
|
axis_text_size |
Numeric size of x- and y-axis labels. Passed to ggplot2
|
legend_title_text_size |
Numeric size of x- and y-axis labels. Passed to
ggplot2
|
... |
Additional parameters for the plotting functions. |
A named list of plot objects:
Factor Time Series Plotspatchwork/ggplot object showing the
estimated factors over time.
Loading Matrix Heatmapggplot object showing a heatmap of the
estimated factor loadings. Zeros are highlighted in black.
Meas. Error Var.-Cov. Matrix Heatmapggplot object showing a
heatmap of the measurement error variance–covariance matrix.
Eigenvalue Plotggplot object showing a bar plot of the
eigenvalues of the measurement error variance–covariance matrix.
Domenic Franjic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.