| plot.SimulData | R Documentation |
Create diagnostic plots for an SimulData object.
## S3 method for class 'SimulData'
plot(x, axis_text_size = 20, legend_title_text_size = 20, ...)
x |
|
axis_text_size |
Numeric size of x- and y-axis labels. Prased to ggplot2
|
legend_title_text_size |
Numeric size of x- and y-axis labels. Prased to
ggplot2
|
... |
Additional parameters for the plotting functions. |
A named list of plot objects:
Factor Time Series Plotspatchwork/ggplot object showing the
simulated factors over time.
Loading Matrix Heatmapggplot object showing a heatmap of the
simulated factor loadings. Zeros are highlighted in black.
Meas. Error Var.-Cov. Matrix Heatmapggplot object showing a
heatmap of the measurement error variance-covariance matrix.
Meas. Error Var.-Cov. Eigenvalue Plotggplotobject showing a bar
plot of the eigenvalues of the measurement error variance-covariance
matrix.
Data Var.-Cov. Matrix Heatmapggplot object showing a heatmap of
the data variance-covariance matrix.
Data Var.-Cov. Eigenvalue Plotggplot object showing a bar plot
of the eigenvalues of the data variance-covariance matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.